# New in 0.16.4 (2022-06-14)

Note: When applying any model using the {class}`~scvi.train.AdversarialTrainingPlan` (e.g. {class}`~scvi.model.TOTALVI`, {class}`~scvi.model.MULTIVI`), you should make sure to use v0.16.4 instead of v0.16.3 or v0.16.2. This release fixes a critical bug in the training plan.

## Changes

## Breaking changes

## Bug Fixes

-   Fix critical issue in {class}`~scvi.train.AdversarialTrainingPlan` where `kl_weight` was overwritten to 0 at each step ([#1566]). Users should avoid using v0.16.2 and v0.16.3 which both include this bug.

## Contributors

-   [@jjhong922]
-   [@adamgayoso]

[#1566]: https://github.com/scverse/scvi-tools/issues/1566
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
